;;; uni-special-lowercase.el --- automatically generated (do not edit)   -*- lexical-binding: t -*-
;; Generated by the `unidata-gen-file' function.

;; This file is part of GNU Emacs.

;;; Commentary:

;; Copyright © 1991-2023 Unicode, Inc.  The sources for this file are
;; found in the admin/unidata/ directory in the Emacs sources.  The
;; Unicode data files are used under the Unicode Terms of Use, as
;; contained in the file copyright.html in that same directory.

;;; Code:

(define-char-code-property 'special-lowercase
  #^[nil nil char-code-property-table nil #^^[1 0 #^^[2 0 nil nil #^^[3 256 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil "i̇" nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil] nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil special-lowercase nil nil nil nil]
  "Unicode unconditional special casing mapping.

Property value is (possibly empty) string or nil.  The value nil denotes that
`lowercase' property should be consulted instead.  A string denotes what
sequence of characters given character maps into.

This mapping includes language- and context-independent special casing rules
defined by Unicode only.  It also does not include association which would
duplicate information from `lowercase' property.")

;; Local Variables:
;; version-control: never
;; no-byte-compile: t
;; no-update-autoloads: t
;; coding: utf-8-emacs-unix
;; End:

;;; uni-special-lowercase.el ends here
