;; In load-path, after this directory should come  -*- lexical-binding: t -*-
;; certain of its subdirectories.  Here we specify them.
(normal-top-level-add-to-load-path '("vc" "use-package" "url" "textmodes" "progmodes" "play" "org" "nxml" "net" "mh-e" "mail" "leim" "language" "international" "image" "gnus" "eshell" "erc" "emulation" "emacs-lisp" "cedet" "calendar" "calc"  "obsolete"))
;; Local Variables:
;; version-control: never
;; no-byte-compile: t
;; no-update-autoloads: t
;; End:
